package com.zkqy.system.service.impl;

import java.util.List;
import com.zkqy.common.utils.DateUtils;
import com.zkqy.system.entity.DragFormGroup;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zkqy.system.mapper.DragFormGroupMapper;
import com.zkqy.system.service.IDragFormGroupService;

/**
 * 动态表单组Service业务层处理
 * 
 * @author hzh
 * @date 2024-01-26
 */
@Service
public class DragFormGroupServiceImpl implements IDragFormGroupService 
{
    @Autowired
    private DragFormGroupMapper dragFormGroupMapper;

    /**
     * 查询动态表单组
     * 
     * @param id 动态表单组主键
     * @return 动态表单组
     */
    @Override
    public DragFormGroup selectDragFormGroupById(Long id)
    {
        return dragFormGroupMapper.selectDragFormGroupById(id);
    }

    /**
     * 查询动态表单组列表
     * 
     * @param dragFormGroup 动态表单组
     * @return 动态表单组
     */
    @Override
    public List<DragFormGroup> selectDragFormGroupList(DragFormGroup dragFormGroup)
    {
        return dragFormGroupMapper.selectDragFormGroupList(dragFormGroup);
    }

    /**
     * 新增动态表单组
     * 
     * @param dragFormGroup 动态表单组
     * @return 结果
     */
    @Override
    public int insertDragFormGroup(DragFormGroup dragFormGroup)
    {
        dragFormGroup.setCreateTime(DateUtils.getNowDate());
        return dragFormGroupMapper.insertDragFormGroup(dragFormGroup);
    }

    /**
     * 修改动态表单组
     * 
     * @param dragFormGroup 动态表单组
     * @return 结果
     */
    @Override
    public int updateDragFormGroup(DragFormGroup dragFormGroup)
    {
        dragFormGroup.setUpdateTime(DateUtils.getNowDate());
        return dragFormGroupMapper.updateDragFormGroup(dragFormGroup);
    }

    /**
     * 批量删除动态表单组
     * 
     * @param ids 需要删除的动态表单组主键
     * @return 结果
     */
    @Override
    public int deleteDragFormGroupByIds(Long[] ids)
    {
        return dragFormGroupMapper.deleteDragFormGroupByIds(ids);
    }

    /**
     * 删除动态表单组信息
     * 
     * @param id 动态表单组主键
     * @return 结果
     */
    @Override
    public int deleteDragFormGroupById(Long id)
    {
        return dragFormGroupMapper.deleteDragFormGroupById(id);
    }
}
